Denomination

Struct Denomination 

pub struct Denomination(pub u8);
Given a number represented as M*B^D, then M is the matissa, B is the base and D is the denomination, represented by this struct.

Tuple Fields

0: u8