pub struct Denomination(pub u8);Expand description
Given a number represented as M*B^D, then
M is the matissa, B is the base and D
is the denomination, represented by this struct.
Tuple Fields
0: u8Trait Implementations
Sourceimpl BorshDeserialize for Denomination
impl BorshDeserialize for Denomination
fn deserialize_reader<__R>(reader: &mut __R) -> Result<Denomination, Error>where
__R: Read,
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSchema for Denomination
impl BorshSchema for Denomination
Sourcefn declaration() -> String
fn declaration() -> String
Get the name of the type without brackets.
Sourcefn add_definitions_recursively(definitions: &mut BTreeMap<String, Definition>)
fn add_definitions_recursively(definitions: &mut BTreeMap<String, Definition>)
Recursively, using DFS, add type definitions required for this type.
Type definition partially explains how to serialize/deserialize a type.
Sourceimpl BorshSerialize for Denomination
impl BorshSerialize for Denomination
Sourceimpl Clone for Denomination
impl Clone for Denomination
Sourcefn clone(&self) -> Denomination
fn clone(&self) -> Denomination
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Denomination
impl Debug for Denomination
Sourceimpl<'de> Deserialize<'de> for Denomination
impl<'de> Deserialize<'de> for Denomination
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Denomination, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Denomination, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<u8> for Denomination
impl From<u8> for Denomination
Sourcefn from(denom: u8) -> Denomination
fn from(denom: u8) -> Denomination
Converts to this type from the input type.
Sourceimpl Hash for Denomination
impl Hash for Denomination
Sourceimpl Ord for Denomination
impl Ord for Denomination
Sourcefn cmp(&self, other: &Denomination) -> Ordering
fn cmp(&self, other: &Denomination) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Denomination
impl PartialEq for Denomination
Sourceimpl PartialOrd for Denomination
impl PartialOrd for Denomination
Sourceimpl Serialize for Denomination
impl Serialize for Denomination
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for Denomination
impl Eq for Denomination
impl StructuralPartialEq for Denomination